@@ -36,7 +36,7 @@ def plot_orderbook(orderbook_df = None, id=False, amount_to_pass =5000, pair='fr
     return fig
 
 
-def plot_order_book(data_df):
+def plot_order_book(data_df=None):
     fig = px.line(data_df, x="price", y="cumulative_quantity", color="type",markers=True,title="order book")
     return fig
 
